// ============================================================================
// ==                                                                        ==
// == AMDiS - Adaptive multidimensional simulations                          ==
// ==                                                                        ==
// ============================================================================
// ==                                                                        ==
// ==  TU Dresden                                                            ==
// ==                                                                        ==
// ==  Institut fr Wissenschaftliches Rechnen                               ==
// ==  Zellescher Weg 12-14                                                  ==
// ==  01069 Dresden                                                         ==
// ==  germany                                                               ==
// ==                                                                        ==
// ============================================================================
// ==                                                                        ==
// ==  https://gforge.zih.tu-dresden.de/projects/amdis/                      ==
// ==                                                                        ==
// ============================================================================

/** \file Serializable.h */

#ifndef AMDIS_SERIALIZABLE_H
#define AMDIS_SERIALIZABLE_H

#include <iostream>
#include <string>

namespace AMDiS {

  /** \brief
   * Interface for JAVA-like serialization of objects. Serializable objects can be
   * written to an out stream and read from an in stream. So i.e. they can be stored
   * on hard disk.
   */
  class Serializable
  {
  public:
    /// Streams the object to output stream out.
    virtual void serialize(std::ostream &out) = 0;

    /// Reads the object from input stream in.
    virtual void deserialize(std::istream &in) = 0;

    /// Returns the type name for this serializable object.
    virtual std::string getTypeName() const 
    { 
      return ""; 
    }

    virtual ~Serializable() {}
  };

}

#endif
